import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class IconScaffoldMenuButtonWidget extends StatelessWidget {
  final IconData? icon;
  final Widget? text;
  final String? tooltip;
  final bool disabled;

  final bool popupButton;
  final List<PopupMenuEntry<dynamic>> Function(BuildContext)? itemBuilder;
  final GestureTapCallback? onTap;

  const IconScaffoldMenuButtonWidget({
    Key? key,
    this.icon,
    this.text,
    this.onTap,
    this.tooltip,
    this.disabled = false,
  })  : itemBuilder = null,
        popupButton = false,
        super(key: key);

  const IconScaffoldMenuButtonWidget.popupButton({
    Key? key,
    this.icon,
    this.text,
    this.itemBuilder,
    this.tooltip,
    this.disabled = false,
  })  : onTap = null,
        popupButton = true,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    GlobalKey<PopupMenuButtonState> popupButtonKey =
        GlobalKey<PopupMenuButtonState>();
    return ExcludeFocusTraversal(
      child: Expanded(
        child: Tooltip(
          message: tooltip!,
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: 5),
            height: 50,
            child: popupButton
                ? PopupMenuButton(
                    key: popupButtonKey,
                    position: PopupMenuPosition.over,
                    child: buildContent(popupButtonKey),
                    itemBuilder: itemBuilder ?? (_) => [],
                  )
                : buildContent(popupButtonKey),
          ),
        ),
      ),
    );
  }

  Widget buildContent(GlobalKey<PopupMenuButtonState> popupButtonKey) {
    return Material(
      color: DefaultColors.background,
      borderRadius: BorderRadius.circular(10),
      child: InkWell(
        borderRadius: BorderRadius.circular(10),
        onTap: popupButton
            ? () => popupButtonKey.currentState?.showButtonMenu()
            : onTap,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Icon(
              icon,
              color: disabled
                  ? DefaultColors.text.withOpacity(0.6)
                  : DefaultColors.text,
            ),
            DefaultTextStyle(
              style: TextStyles.textStyleSize(13).copyWith(
                  color: disabled ? DefaultColors.text.withOpacity(0.6) : null),
              overflow: TextOverflow.ellipsis,
              child: text!,
            )
          ],
        ),
      ),
    );
  }
}
