import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class DefaultMenuBar extends StatefulWidget {
  final List<Widget?>? menuButtons;

  const DefaultMenuBar({
    Key? key,
    this.menuButtons,
  }) : super(key: key);

  @override
  State<DefaultMenuBar> createState() => _DefaultMenuBarState();
}

class _DefaultMenuBarState extends State<DefaultMenuBar> {
  @override
  Widget build(BuildContext context) {
    var children = widget.menuButtons?.whereNotNull() ?? [];
    return children.length > 0 ? buildBar(children) : Container(height: 0);
  }

  Widget buildBar(List<Widget> children) {
    var rowChildren = <Widget>[];

    if (children.every((x) => x is IconScaffoldMenuButtonWidget) &&
        children.length > 4) {
      rowChildren.addAll(children.sublist(0, 3));
      var extraChildren = children.sublist(3);
      rowChildren.add(IconScaffoldMenuButtonWidget.popupButton(
        icon: Icons.more_vert,
        text: Text("Mehr"),
        tooltip: "Mehr Optionen",
        key: Key("more_options"),
        itemBuilder: (context) => extraChildren
            .map((e) => PopupMenuItem(
                  child: IconTheme(
                    data: IconThemeData(size: 23, color: DefaultColors.text),
                    child: Row(
                      children: [
                        Icon((e as IconScaffoldMenuButtonWidget).icon),
                        Container(width: 8),
                        Text(
                          e.tooltip ?? "?",
                          style: TextStyle(color: DefaultColors.text),
                        )
                      ],
                    ),
                  ),
                  onTap: e.onTap,
                ))
            .toList(),
      ));
    } else {
      rowChildren.addAll(children);
    }

    return Container(
      height: 60,
      color: DefaultColors.background,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: rowChildren,
      ),
    );
  }
}
