import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class SimpleScaffoldMenuButtonWidget extends StatelessWidget {
  final Text? text;
  final String? tooltip;

  final bool popupButton;
  final List<PopupMenuEntry<dynamic>> Function(BuildContext)? itemBuilder;
  final GestureTapCallback? onTap;

  const SimpleScaffoldMenuButtonWidget(
      {Key? key, required this.text, this.onTap, this.tooltip})
      : popupButton = false,
        itemBuilder = null,
        super(key: key);

  const SimpleScaffoldMenuButtonWidget.popupButton(
      {Key? key, required this.text, this.itemBuilder, this.tooltip})
      : popupButton = true,
        this.onTap = null,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    GlobalKey<PopupMenuButtonState> popupButtonKey =
        GlobalKey<PopupMenuButtonState>();
    return ExcludeFocusTraversal(
      child: Expanded(
          child: Tooltip(
        message: tooltip,
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 5),
          height: 50,
          child: popupButton
              ? PopupMenuButton(
                  key: popupButtonKey,
                  position: PopupMenuPosition.over,
                  child: buildContent(popupButtonKey),
                  itemBuilder: itemBuilder ?? (_) => [],
                )
              : buildContent(popupButtonKey),
        ),
      )),
    );
  }

  Widget buildContent(GlobalKey<PopupMenuButtonState> popupButtonKey) {
    return Material(
      color: DefaultColors.background,
      borderRadius: BorderRadius.circular(10),
      child: InkWell(
        borderRadius: BorderRadius.circular(10),
        onTap: popupButton
            ? () => popupButtonKey.currentState?.showButtonMenu()
            : onTap,
        child: Center(
          child: DefaultTextStyle(
              style: TextStyles.textStyleSize(19).copyWith(
                  color: DefaultColors.accent, fontWeight: FontWeight.w600),
              child: text!),
        ),
      ),
    );
  }
}
